@@ -44,19 +44,38 @@ mod error;
 #[doc(hidden)]
 pub mod idl;
 mod loader;
+mod program;
 mod program_account;
+mod signer;
 pub mod state;
+mod system_program;
 mod sysvar;
+mod unchecked_account;
 mod vec;
 
 pub use crate::account::Account;
-pub use crate::context::{Context, CpiContext, CpiStateContext};
+#[doc(hidden)]
+#[allow(deprecated)]
+pub use crate::context::CpiStateContext;
+pub use crate::context::{Context, CpiContext};
+#[doc(hidden)]
+#[allow(deprecated)]
 pub use crate::cpi_account::CpiAccount;
+#[doc(hidden)]
+#[allow(deprecated)]
 pub use crate::cpi_state::CpiState;
 pub use crate::loader::Loader;
+pub use crate::program::Program;
+#[doc(hidden)]
+#[allow(deprecated)]
 pub use crate::program_account::ProgramAccount;
+pub use crate::signer::Signer;
+#[doc(hidden)]
+#[allow(deprecated)]
 pub use crate::state::ProgramState;
+pub use crate::system_program::System;
 pub use crate::sysvar::Sysvar;
+pub use crate::unchecked_account::UncheckedAccount;
 pub use anchor_attribute_access_control::access_control;
 pub use anchor_attribute_account::{account, declare_id, zero_copy};
 pub use anchor_attribute_error::error;
@@ -206,6 +225,11 @@ pub trait Owner {
     fn owner() -> Pubkey;
 }
 
+/// Defines the id of a program.
+pub trait Id {
+    fn id() -> Pubkey;
+}
+
 /// Defines the Pubkey of an account.
 pub trait Key {
     fn key(&self) -> Pubkey;
@@ -223,11 +247,14 @@ pub mod prelude {
     pub use super::{
         access_control, account, declare_id, emit, error, event, interface, program, require,
         state, zero_copy, Account, AccountDeserialize, AccountSerialize, Accounts, AccountsExit,
-        AnchorDeserialize, AnchorSerialize, Context, CpiAccount, CpiContext, CpiState,
-        CpiStateContext, Key, Loader, ProgramAccount, ProgramState, Sysvar, ToAccountInfo,
-        ToAccountInfos, ToAccountMetas,
+        AnchorDeserialize, AnchorSerialize, Context, CpiContext, Key, Loader, Owner, Program,
+        ProgramAccount, Signer, System, Sysvar, ToAccountInfo, ToAccountInfos, ToAccountMetas,
+        UncheckedAccount,
     };
 
+    #[allow(deprecated)]
+    pub use super::{CpiAccount, CpiState, CpiStateContext, ProgramState};
+
     pub use borsh;
     pub use solana_program::account_info::{next_account_info, AccountInfo};
     pub use solana_program::entrypoint::ProgramResult;
