@@ -10,17 +10,17 @@ declare_id!("Fg6PaFpoGXkYsidMpWTK6W2BeZ7FEfcYkg476zPFsLnS");
 #[derive(Accounts)]
 pub struct GenericsTest<'info, T, U, const N: usize>
 where
-    T: AccountSerialize + AccountDeserialize + Clone,
+    T: AccountSerialize + AccountDeserialize + Owner + Clone,
     U: BorshSerialize + BorshDeserialize + Default + Clone,
 {
     pub non_generic: AccountInfo<'info>,
-    pub generic: ProgramAccount<'info, T>,
-    pub const_generic: Loader<'info, Account<N>>,
-    pub associated: CpiAccount<'info, Associated<U>>,
+    pub generic: Account<'info, T>,
+    pub const_generic: Loader<'info, FooAccount<N>>,
+    pub associated: Account<'info, Associated<U>>,
 }
 
 #[account(zero_copy)]
-pub struct Account<const N: usize> {
+pub struct FooAccount<const N: usize> {
     pub data: WrappedU8Array<N>,
 }
 
